/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jmeter.protocol.http.sampler;

import org.apache.jmeter.extractor.BoundaryExtractor;
import org.apache.jmeter.protocol.http.util.HTTPConstants;
import org.apache.jmeter.samplers.SampleResult;
import org.apache.jmeter.threads.JMeterContext;
import org.apache.jmeter.threads.JMeterVariables;
import org.apache.jmeter.util.JMeterContextExtension;
import org.apache.jmeter.wiremock.WireMockExtension;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;

import com.github.tomakehurst.wiremock.WireMockServer;
import com.github.tomakehurst.wiremock.client.WireMock;

@ExtendWith(WireMockExtension.class)
@ExtendWith(JMeterContextExtension.class)
public class BoundaryExtractorRedirectsTest {
    @Test
    public void test(WireMockServer server, JMeterVariables vars, JMeterContext ctx) {
        server.stubFor(WireMock.get("/index.html")
                .willReturn(
                        WireMock.aResponse()
                                .withHeader("Content-Type", "text/html; encoding=utf-8")
                                .withBody("<html><body><img src='/img1.png'></body>")));
        server.stubFor(WireMock.get("/img1.png")
                .willReturn(
                        WireMock.aResponse()
                                .withHeader("Content-Type", "text/html; encoding=utf-8")
                                .withBody("Image1: [val1]")));


        HTTPSamplerBase http = HTTPSamplerFactory.newInstance(HTTPSamplerFactory.IMPL_JAVA);
        http.setDomain("localhost");
        http.setPort(server.port());
        http.setConnectTimeout("2000");
        http.setResponseTimeout("4000");
        http.setMethod(HTTPConstants.GET);
        http.setPath("/index.html");
        http.setFollowRedirects(true);
        http.setUseKeepAlive(true);
        http.setRunningVersion(true);
        http.setImageParser(true);

        SampleResult result = http.sample();
        ctx.setPreviousResult(result);

        BoundaryExtractor be = new BoundaryExtractor();
        be.setMatchNumber(0);
        be.setLeftBoundary("[");
        be.setRightBoundary("]");
        be.setRefName("va");
        be.setRunningVersion(true);
        be.process();
//        Assertions.assertEquals("final", vars.get(be.getRefName()),
//                "The page after 5-6 redirects contains [final], and it should be extracted");
    }

}
